/*-----------------------------------------------------------------------------------------
 LIBRARY: RENEWABLE
 FILE: BombaRiego
 CREATION DATE: 07/06/2016
-----------------------------------------------------------------------------------------*/
USE MATH


COMPONENT BombaRiego
	"Bomba de impulsin de agua del pozo al tanque de almacenamiento"

/* 
La bomba toma el agua del pozo 
Dimensiones del Pozo: 15 metros de profundidad y caudal 3m3/h
Area del tanque de alimentacion 1.5m2
Altura del tanque de alimentacion 3.5
Volumen total del tanque de alimentacion 5.25m3
Distancia entre el tanque y la bomba 10m
Tipo SP 3A-6
Number of Product: 10007106 
La bomba B-04 se enciende para llenar el tanque de 5.25m3, luego se apaga,
asi se calcula los tiempos de encendido y apagado de la bomba feed B-04 en
funcion del llenado o vaciado del tanque
Tiene un flujo fijo de 3m3/h 
Volt= Amplitud del Voltaje de red --- 3 x 400 Volts sistema balanceado
Conexion estrella 380-415 V  */

PORTS


----------------------------------------------------------------------
-- Entrada: 
-- Activacin de la bomba de alimentacin
-- n=1 cuando la bomba B04 esta prendida y 0 cuando esta apagada
----------------------------------------------------------------------

	 	IN ContBomb						ContBombb
		IN caudalpuerto				caudalpuertob
		
----------------------------------------------------------------------
-- Salidas: 
-- Potencia activa y reactiva
-- Flujo de la bomba B04
----------------------------------------------------------------------

		OUT Pcargagrid						Pcargagridb
		OUT CaudalBomba					CaudalBombab
		


DATA 
	
	REAL ro=1000				" Densidad del Agua (Kg/m3)"
	--REAL q=3						" Caudal real fijado (m3/h)"
	REAL H=25.7					" Altura Resultante de la bomba (m)"
	REAL g=9.81					" Aceleracion de gravedad (m/seg2)"
	REAL cosphi=0.77			" Factor de potencia"	
	REAL EtaMotor=98     " Eficiencia del motor fija (%)"
	REAL EtaPump=98     " Eficiencia de la bomba (%)"	
	
DECLS

	REAL P1						" Potencia de entrada al motor (W)"
	REAL P2						" Potencia de salida del Motor o Potencia de entrada a la bomba (W)"
	REAL Phyd					" Potencia de salida de la bomba (W)"
	REAL qnew					" Caudal real fijado (m3/s)"
	REAL S						" Potencia aparente"
	REAL Q						" Potencia reactiva (VAR)"
	REAL nbomba
	REAL qin
		
INIT
	
	nbomba=0
    	     
CONTINUOUS


	nbomba=ContBombb.nbomba
	qin=caudalpuertob.qin

	qnew=qin*nbomba		
	--qnew=(q/3600)*nfeed					-- Caudal real fijado [m3/s]
	Phyd=ro*g*H*qnew 
	P2=Phyd*100/EtaPump       
	--P1=P2*100/(EtaMotor*3) 
	S=P2/cosphi    
	Q=S*sin(acos(cosphi))
	
	Pcargagridb.Pact=P2
	Pcargagridb.Qreact=Q
	CaudalBombab.q=qnew
		
END COMPONENT