USE MATH


--*************************************************************************

--*************************************************************************
-- Este modulo lee la frecuencia y la potencia de red
-- Y en funcion de ello define la potencia limite

COMPONENT FSPCSolar

PORTS
		
---------------------------------------------------------------------------
--        Transformer - FSPC
----------------------------------------------------------------------------
		
 		IN FSPCT			FSPCTb	
		
---------------------------------------------------------------------------
--        FSPC  - Reference Voltage Defined
----------------------------------------------------------------------------

		OUT  FSPCRVD  			FSPCRVDa

	
DATA

	REAL Fo=50							"Frecuencia fundamental (Hz)"
				
DECLS

-- Variables de Entrada

	REAL Fg							"Grid Frequency (Hz)"
	REAL Pg							"Output Power grid (W)"
	REAL Ig							"Grid Current (Amps)"
	REAL Ug							"Grid Voltage (Volts)"
	REAL PorPg						"Limitacion de Potencia"
	REAL Fgm							"Memoria de la Frecuencia"
	REAL Plimit
	REAL Plimitant
	
	
INIT

	Fgm=50
	
CONTINUOUS

	-- Lecturas de la corriente y el voltaje de red
	
	Ig=FSPCTb.Ig
	Ug=FSPCTb.Ug

	-- Buscar Fg y Pg en funcion de Ig y Pg
	
	SEQUENTIAL	
			
							IF (abs(Fg-Fgm)> 0.01) THEN   -- La pregunta es si existen o no cambios de Frecuencia
							
									
									IF (Fg>=52) THEN
									PorPg=0
									
									ELSEIF (Fg<=45) THEN
									PorPg=0
									
									ELSEIF (Fg>45 AND Fg<=51) THEN
									PorPg=1
									
									ELSE 	PorPg=3//-Fg+52
									
									END IF	
							
							Plimit=Pg*PorPg
							
							ELSE
							
							Plimit=Plimitant
							
							END IF
	
	END SEQUENTIAL
	
	Fgm=Fg
	Plimitant=Plimit
	
	
	FSPCRVDa.Plimit=Plimit
	
	 	
END COMPONENT

--*************************************************************************

--*************************************************************************
-- Reference Voltage Defined
-- Este modulo define el voltage de referencia en funcion
-- del limite de potencia definido previamente
-- incluye un limitador y MPPT

COMPONENT RefVDf

PORTS
		
---------------------------------------------------------------------------
--                  Reference Voltage Defined - FSPC 
----------------------------------------------------------------------------

		IN  FSPCRVD  			FSPCRVDb

---------------------------------------------------------------------------
--                  Reference Voltage Defined - PV Solar
----------------------------------------------------------------------------

		IN  RVDPVS  			RVDPVSa
		
---------------------------------------------------------------------------
--                  Reference Voltage Defined - Voltage Controller
----------------------------------------------------------------------------

		OUT  RVDVC  			RVDVCa
	
DATA	

	REAL C=0.1					"Paso"
				
DECLS

	REAL	Plimit				"Potencia limite para el sistema solar (W)"
	REAL  Upv					"Voltaje de salida del Panel Solar (Volts)"
	REAL  Ipv					"Corriente de salida del Panel Solar (Amps)"
	REAL  Ppv					"Potencia de salida del Panel Solar (Amps)"
	REAL  Upvref				"Reference Voltage (Volts)"
	REAL  Ppvant				"Output Power PV Array t-1 (W)"
	REAL  Upvant				"Output Voltage PV Array t-1 (Volts)"
	REAL  Ppvantb				"Output Power PV Array t-2 (W)"
	REAL  Upvantb				"Output Voltage PV Array t-2 (Volts)"
	REAL  parada
	REAL  paradal
	
	
INIT
	
DISCRETE

   WHEN ((Ppv>Plimit))THEN   -- Activa el modulo de Limitacion
      
      paradal=0				
 	
   END WHEN
     
	      
CONTINUOUS

	Upv=RVDPVSa.Vdc
	Ipv=RVDPVSa.Idc
	Plimit=FSPCRVDb.Plimit
	
	
SEQUENTIAL
	
	Ppv=Upv*Ipv
	
	----------------------------------------------------------------
	-- Algoritmo de cambio entre limitacion y optimizacion
	----------------------------------------------------------------
		
	IF ((paradal==0)) THEN    -- Si esta activado el modulo de Limitacion
	parada=1                  -- Desactivar el modulo de optimizacion
	
	ELSE 		
	
		  -- Si el modulo de optimizacion esta desactivado, y la potencia varia mucho,
		  -- Entonces activar el modulo de optimizacion
		  
						IF ((parada==1) AND (abs(Ppv-Ppvant)>=100)) THEN   
						parada=0

	  	-- Si el modulo de optimizacion esta desactivado, y la potencia NO varia mucho,
		-- Entonces mantener desactivado el modulo de optimizacion
						
						ELSEIF ((parada==1) AND (abs(Ppv-Ppvant)<100)) THEN
						parada=1
						
						END IF
	
	END IF
		
	----------------------------------------------------------------
	-- Algoritmo de Limitacion
	----------------------------------------------------------------
	
	IF (paradal==0)THEN
		
			IF((Ppv>Ppvant))THEN
				
						IF(Upv>Upvant) THEN
						Upvref=Upvref-C			
						ELSE
						Upvref=Upvref+C	
						END IF
					
			ELSE
			
						IF(Ppv<Plimit) THEN
						paradal=1
								
						ELSE
									IF(Upv>Upvant) THEN
									Upvref=Upvref+C		
									ELSE
									Upvref=Upvref-C	
									END IF	
							
						END IF
						
			END IF
	
	END IF
	
				
	----------------------------------------------------------------
	-- Algoritmo de seguimiento del Punto de Mxima Potencia
	----------------------------------------------------------------
				
   IF (parada==0)THEN
		
				IF((Ppv>Ppvant))THEN
				
						IF(Upv>Upvant) THEN
						Upvref=Upvref+C			
						ELSE
						Upvref=Upvref-C	
						END IF
				
				ELSE
				
						IF(Ppvant>Ppvantb) THEN
						Upvref=Upvant
						parada=1
								
						ELSE
					
					 			IF(Upv>Upvant) THEN
						 		Upvref=Upvref-C
								ELSE
								Upvref=Upvref+C	
								END IF
							
						END IF
						
				END IF
	
	END IF
		
	Ppvantb=Ppvant
  	Upvantb=Upvant
	Ppvant=Ppv
	Upvant=Upv
  


END SEQUENTIAL	


	RVDVCa.Uref=Upvref	
	 	
END COMPONENT

--*************************************************************************

--*************************************************************************
-- Voltage Controller 

COMPONENT VoltageController

-- El objetivo del presente modulo es la modulacion del controlador por el lado del Boost
-- sus resultados estarn incluidos en el resto de la simulacion

PORTS

----------------------------------------------------------------------------
-- Relacion PV array - Voltage Controller
----------------------------------------------------------------------------
		
	IN PVBCV 			pvbcvb     -- Voltaje del arreglo solar

----------------------------------------------------------------------------
--                  Reference Voltage Defined - Voltage Controller
----------------------------------------------------------------------------

	IN  RVDVC  			RVDVCb 	

----------------------------------------------------------------------------	
-- relacion controlador PI con el PWM
----------------------------------------------------------------------------

	OUT PIPWMS  		pipwmsa    -- seal de modulacion PWM

DATA
   
   REAL Kp					"PI controller (--)"
   REAL Ki					"PI controller (--)"
   	
      
DECLS
	
	REAL Upv					"Output Voltage PV array t (Volts)"
	REAL Upvref				"Output Reference Voltage PV array t (Volts)"
	REAL senal				"Seal de modulacion del PWM"
	REAL x					"Auxiliar para construir el controlador PI"
		
INIT
  
 
    	     
CONTINUOUS

	Upv=pvbcvb.Vdc
	Upvref=RVDVCb.Uref
	
	x'=Upvref-Upv
	
	senal=Kp*(Upvref-Upv)+Ki*x
		
	pipwmsa.senal=senal
	

END COMPONENT

--*************************************************************************

--*************************************************************************
-- Modulacion PWM 


COMPONENT PWM

-- El objetivo del presente modulo es la modulacion del controlador por el lado del Boost
-- sus resultados estarn incluidos en el resto de la simulacion

PORTS

-- relacion Voltage controller con el PWM
	IN PIPWMS  		pipwmsb    -- seal de modulacion PWM

-- relacion Boost con el PWM

	OUT CPWMS  		cpwmsb    -- Modulador del Boost circuit	
	

DATA

	REAL period				" Signal  period sawtooth (ms)"
	REAL Am					" Signal amplitude sawtooth (--)"
	  	
      
DECLS
	
	REAL senal				"Seal de modulacion del PWM"
	REAL K					"Modulacion PWM"
	REAL sawtooth			"Diente de Sierra"
	
		
INIT
  
     	     
CONTINUOUS

	senal=pipwmsb.senal
	
	sawtooth=Am*ramp(TIME,period)
	
	K= ZONE (senal>sawtooth) 1
	   OTHERS 0
	
	cpwmsb.s=K

END COMPONENT


--*************************************************************************
--		OTROS EXPERIMENTOS
--*************************************************************************


-- MPP Tracking 
 
COMPONENT MPPTracking

-- El objetivo del presente modulo es la modulacion del Sunny Boy
-- sus resultados estarn incluidos en el resto de la simulacion

PORTS
  	
-- relacion array PV con el MPP Tracking
		IN PVMPPTI  		pvmpptib    -- Corriente resultante del modulo
		IN PVMPPTV  		pvmpptvb    -- Voltaje de entrada fijado por el boost converter

-- relacion el MPP Tracking con el Voltage Controller

		OUT MPPPIV  		mpppiva    -- Voltaje de referencia del algoritmo de MPPT  	

DATA
   
   	REAL C=1					"Rated reference voltage (--)"
      
DECLS
		REAL Upv					"Output Voltage PV array t (Volts)"
		REAL Ipv					"Output corrent PV array t (Amps)"
		REAL Ppv					"Output power PV array t (W)"
		REAL Ppvant				"Output Power PV Array t-1 (W)"
		REAL Upvant				"Output Voltage PV Array t-1 (Volts)"
		REAL Ppvantb			"Output Power PV Array t-2 (W)"
		REAL Upvantb			"Output Voltage PV Array t-2 (Volts)"
		REAL Upvref				"Output reference Voltage PV Array (Volts)"
		REAL aux					"Auxiliar"
		
INIT
  
  Ppvant=0
  Upvant=0
  Ppvantb=0
  Upvantb=0
  aux=1
    	     
CONTINUOUS
	
	Upv=pvmpptvb.Vdc
	Ipv=pvmpptib.Idc
	

SEQUENTIAL
	
	Ppv=Upv*Ipv
	
	IF ((aux==0) AND (abs(Ppv-Ppvant)>=100))	THEN
	aux=1
	Upvref=Upvref+C			
	 				 
	 
	ELSEIF ((aux==0) AND (abs(Ppv-Ppvant)<100))	THEN
	 aux=0
	 
	ELSE 
	
				IF((Ppv>Ppvant))THEN
				
						IF(Upv>Upvant) THEN
						Upvref=Upvref+C			
						
						ELSE
						Upvref=Upvref-C	
						END IF
				
				ELSE
				
						IF(Ppvant>Ppvantb) THEN
						aux=0
								
						ELSE
					
					 			IF(Upv>Upvant) THEN
						 		Upvref=Upvref-C
						 			
								ELSE
								Upvref=Upvref+C	
								END IF
							
						END IF
						
				END IF
	
	END IF	

  	Ppvantb=Ppvant
  	Upvantb=Upvant
	Ppvant=Ppv
	Upvant=Upv


END SEQUENTIAL		

   mpppiva.Vref=Upvref

END COMPONENT