USE MATH

-- Fecha de Actualizacion: 28/04/2012

COMPONENT FeedPump
	"Bomba de impulsin de agua del pozo al tanque de alimentacin 'B04'"

/* 
La bomba B04 toma el agua del pozo 
Dimensiones del Pozo: 15 metros de profundidad y caudal 3m3/h
Area del tanque de alimentacion 1.5m2
Altura del tanque de alimentacion 3.5
Volumen total del tanque de alimentacion 5.25m3
Distancia entre el tanque y la bomba 10m
Tipo SP 3A-6
Number of Product: 10007106 
La bomba B-04 se enciende para llenar el tanque de 5.25m3, luego se apaga,
asi se calcula los tiempos de encendido y apagado de la bomba feed B-04 en
funcion del llenado o vaciado del tanque
Tiene un flujo fijo de 3m3/h 
Volt= Amplitud del Voltaje de red --- 3 x 400 Volts sistema balanceado
Conexion estrella 380-415 V  */

PORTS


----------------------------------------------------------------------
-- Entrada: 
-- Activacin de la bomba de alimentacin
-- n=1 cuando la bomba B04 esta prendida y 0 cuando esta apagada
----------------------------------------------------------------------

	 	IN CHFeedB						CHFeedBa
		
----------------------------------------------------------------------
-- Salidas: 
-- Potencia activa y reactiva
-- Flujo de la bomba B04
----------------------------------------------------------------------

		OUT Pcargagrid						Pcargagridb
		OUT B04Tanq1						B04Tanq1b
		


DATA 
	
	REAL ro=1000				" Densidad del Agua (Kg/m3)"
	REAL q=3						" Caudal real fijado (m3/h)"
	REAL H=25.7					" Altura Resultante de la bomba (m)"
	REAL g=9.81					" Aceleracion de gravedad (m/seg2)"
	REAL cosphi=0.77			" Factor de potencia"	
	REAL EtaMotor=54.97     " Eficiencia del motor fija (%)"
	REAL EtaPump=55.8       " Eficiencia de la bomba (%)"	
	
DECLS

	REAL P1						" Potencia de entrada al motor (W)"
	REAL P2						" Potencia de salida del Motor o Potencia de entrada a la bomba (W)"
	REAL Phyd					" Potencia de salida de la bomba (W)"
	REAL qnew					" Caudal real fijado (m3/s)"
	REAL S						" Potencia aparente (VAR)"
	REAL Q						" Potencia reactiva"
	REAL nfeed
		
INIT
	
	nfeed=1
    	     
CONTINUOUS

	nfeed=CHFeedBa.nfeed

	qnew=(q/3600)*nfeed					-- Caudal real fijado [m3/s]
	Phyd=ro*g*H*qnew 
	P2=Phyd*100/EtaPump       
	P1=P2*100/(EtaMotor*3) 
	S=P1/cosphi    
	Q=S*sin(acos(cosphi))
	
	Pcargagridb.Pact=P1
	Pcargagridb.Qreact=Q
	B04Tanq1b.q=qnew
		
END COMPONENT

COMPONENT BombaDesplazamiento
	"Bomba de alimentacin al sistema de presurizacin 'B01'"
/*
La bomba B01 es la bomba de alimentacion
Tipo CHI2 - 60 A-W-G-B-BQQP
Number of Product: 4H518006
La bomba B-01 esta prendida en operacion y se apaga en limpieza
*/

PORTS

----------------------------------------------------------------------
-- Entrada:
-- Altura del tanque 1
-- Activacin de la bomba de desplazamiento 
----------------------------------------------------------------------
		IN Tanq1B01							Tanq1B01a
		IN CHB01								CHB01a
		
----------------------------------------------------------------------
-- Salidas: 
-- Potencia activa y reactiva
-- Diferencia de Presion de la bomba B01
----------------------------------------------------------------------

		OUT DPB01							DPB01b	
		OUT B01Tanq1						B01Tanq1b


DATA 
	
	REAL ro=1000						" Densidad del Agua (Kg/m3)"
	REAL g=9.81							" Aceleracion de gravedad (m/seg2)"
	REAL cosphiB01=0.89				" Factor de potencia"	
	REAL EtaMB01=0.6895    			" Eficiencia del motor fija"
	REAL EtaB01=38.4       			" Eficiencia de la bomba (%)"
	REAL Patm=1                   " Presion Atmosferica (bar)"
	REAL AreaT1=1.5               " Area del tanque T1 (m)"
	REAL tiempo=46800					" Hora en que se realiza la limpieza (seg)"
	
	
	
DECLS

	REAL hB01							" Altura de la bomba de desplazamiento (m)"
	REAL q								" Caudal (m3/h)" 
	REAL qnew							" Caudal (m3/seg)" 
	REAL P1B01							" Potencia de entrada al motor (W)"
	REAL P2B01							" Potencia de salida del Motor o Potencia de entrada a la bomba (W)"
	REAL PhydB01						" Potencia de salida de la bomba (W)"
	REAL SB01							" Potencia aparente (VAR)"
	REAL QB01							" Potencia reactiva"
	REAL DP01							" Diferencia de Presion (bar)"
	REAL Ve								" Velocidad en la boquila del Tanque T1 (m/seg)"
	REAL Pinit							" Presion en la boquilla del tanque T1 (bar)"
	REAL HT1								" Altura del tanque 1 (m)"
	REAL nclean							" Variable interna"
	REAL nfillCL						" Variable interna"
	REAL ndes							" Activacin de la bomba de desplazamiento"

		
INIT

	nclean=0 
 	nfillCL=0
	
DISCRETE

       WHEN ((TIME>=tiempo) AND (TIME<(tiempo+810)))THEN  -- Limpiar
 				nclean=1 
 				nfillCL=0
       END WHEN
       
       WHEN ((TIME>=(tiempo+810)) AND (TIME<(tiempo+2066.6)))THEN  -- Limpiar
 				nclean=1 
 				nfillCL=1
       END WHEN
       
       WHEN ((TIME<tiempo) OR (TIME>=(tiempo+2066.6)))THEN   -- Solo se desalina
 				nclean=0
 				nfillCL=0
       END WHEN
           
    	     
CONTINUOUS

	HT1=Tanq1B01a.HT1
	ndes=CHB01a.ndes
	
	q= ZONE ((nclean==0) AND (ndes==1)) 2.5					-- Desalinizacion
	   ZONE (nfillCL==1) 1.5										-- Llenado del tanque de limpieza
	 	OTHERS 0															-- Vaciando el tanque de limpieza
	
	qnew=q/3600						-- Caudal real fijado [m3/s]
	
	   	                                       
	hB01=56.2-(3.5334*q)-(1.5333*(q**2))
	
	PhydB01=ro*g*hB01*qnew
	 	
	
   P2B01=PhydB01*100/EtaB01                                  
	P1B01=P2B01/(EtaMB01*3)                                   
	SB01=P1B01/cosphiB01                                      
	QB01= SB01*sin(acos(cosphiB01)) 
	                              
   DP01= ZONE ((nclean==1) AND (nfillCL==0)) 0						-- Vaciando el tanque de limpieza
   		ZONE ((ndes==0)) 0
         OTHERS ro*g*hB01/100000     
                                      
	Ve=qnew/AreaT1             
	                      
	Pinit=ZONE ((nclean==1) AND (nfillCL==0)) 0
			ZONE ((ndes==0)) 0
         OTHERS Patm+(ro*g*HT1/100000)+(0.5*ro*Ve*Ve/100000)
	 
	DPB01b.DP01=DP01    
	DPB01b.Pinit=Pinit
	DPB01b.q=qnew						-- Caudal real fijado [m3/s]
	DPB01b.P=P1B01
	DPB01b.Q=QB01
	  
	B01Tanq1b.q=qnew
              
		
END COMPONENT

COMPONENT BombaCL
	"Bomba de recirculacin y limpieza de la planta desaladora 'B02'"

/*
La bomba B02 es la bomba de Limpieza
Tipo CHI4 - 60 A-W-G-B-BQQV
Number of Product: 4J518006
La bomba B-02 esta prendida en la limpieza y se apaga en la operacion normal
Consideremos un flujo constante 3 m3/h
*/

PORTS

----------------------------------------------------------------------
-- Salidas: Potencia activa y reactiva
-- Flujo desde el tanque de limpieza
----------------------------------------------------------------------
		OUT CLB02							CLB02b
		OUT B02Tanqcl						B02Tanqclb

DATA 
	
	REAL ro=1000							" Densidad del Agua (Kg/m3)"
	REAL g=9.81								" Aceleracion de gravedad (m/seg2)"	
	REAL cosphiB02=0.8912				" Factor de potencia"	
	REAL EtaMB02=0.6626    				" Eficiencia del motor fija"
	REAL EtaB02=48.4       				" Eficiencia de la bomba (%)"	
	REAL Patm=1                      " Presion Atmosferica (bar)" 
	REAL tiempo=46800						" Hora en que se realiza la limpieza (seg)"
	
DECLS

	
	REAL q									" Caudal (m3/h)" 
	EXPL REAL hB02							" Altura de la bomba de desplazamiento (m)"
	EXPL REAL qnew							" Caudal (m3/s)" 
	EXPL REAL P1B02						" Potencia de entrada al motor (W)"
	EXPL REAL P2B02						" Potencia de salida del Motor o Potencia de entrada a la bomba (W)"
	EXPL REAL PhydB02						" Potencia de salida de la bomba (W)"
	EXPL REAL SB02							" Potencia aparente (VAR)"
	EXPL REAL QB02							" Potencia reactiva"
	EXPL REAL DP02							" Diferencia de Presion (bar)"
	EXPL REAL Pinit						" Presion en la boquilla del tanque de limpieza (bar)"
	REAL nclean								
	REAL nfillCL
		
INIT

	nclean=0 
 	nfillCL=0
	
DISCRETE

       WHEN ((TIME>=tiempo) AND (TIME<(tiempo+810)))THEN  -- Limpiar membrana
 				nclean=1 
 				nfillCL=0
       END WHEN
       
       WHEN ((TIME>=(tiempo+810)) AND (TIME<(tiempo+2066.6)))THEN  -- Llenado del tanque de limpieza
 				nclean=1 
 				nfillCL=1
       END WHEN
       
       WHEN ((TIME<tiempo) OR (TIME>=(tiempo+2066.6)))THEN   -- Solo se desalina
 				nclean=0
 				nfillCL=0
       END WHEN
    	     
CONTINUOUS

	q= ZONE ((nclean==1) AND (nfillCL==0)) 2    -- Limpieza de la membrana
	   OTHERS 0
	   
	hB02=57.5-(1.1*q)-(0.5680*(q**2))
	
	qnew=q/3600						-- Caudal real fijado [m3/s]
	
	PhydB02=ro*g*hB02*qnew 
	   		                        
	P2B02=PhydB02*100/EtaB02                                   
	P1B02=P2B02/(EtaMB02*3)                                    
	SB02=P1B02/cosphiB02                                      
	QB02= SB02*sin(acos(cosphiB02))   
	
	DP02= ZONE ((nclean==0) OR (nfillCL==1)) 0
	      OTHERS ro*g*hB02/100000
	
	Pinit=ZONE ((nclean==0) OR (nfillCL==1)) 0
	      OTHERS Patm                                             
	
	CLB02b.DP02=DP02    
	CLB02b.Pinit=Pinit  
	CLB02b.q=qnew         			-- Caudal real fijado [m3/s]       
	CLB02b.P=P1B02
	CLB02b.Q=QB02                                         
	
	B02Tanqclb.q=qnew                        
		
END COMPONENT

COMPONENT BombaHP
	"Bomba de alta presin para filtracin salina 'B03'"
    
/*
La bomba B03 es la bomba de Alta presion
Tipo BMP 2.2 R-A-O-A-BBVP
Number of Product: 96615387
La bomba B-03 siempre esta predinda tanto para las limpiezas como en
operacion normal, en este caso, nos enfocaremos en la operacion normal
*/

PORTS

----------------------------------------------------------------------
-- Entradas: 
-- Diferencia de Presion de la bomba B01
-- Activacin de la rama de desalinizacion
----------------------------------------------------------------------
	
		IN DPB01							   DPB01a	
		IN CLB02							   CLB02a				

----------------------------------------------------------------------
-- Salidas: Potencia activa y reactiva
-- Flujo hacia el tanque de limpieza
----------------------------------------------------------------------
		OUT Pcargagrid						Pcargagridb
		OUT B03Mem							B03Memb
		

DATA 
	
	REAL ro=1000						" Densidad del Agua (Kg/m3)"
	REAL g=9.81							" Aceleracion de gravedad (m/seg2)"	
	REAL cosphiB03=0.86				" Factor de potencia"	
	REAL EtaMB03=0.886    			" Eficiencia del motor fija"
	REAL EtaB03=91.5584       		" Eficiencia de la bomba (%)"
		
	
DECLS

	REAL hB03							" Altura de la bomba de desplazamiento (m)"
	REAL q								" Caudal (m3/h)" 
	REAL qnew							" Caudal (m3/s)" 
	REAL P1B03							" Potencia de entrada al motor (W)"
	REAL P2B03							" Potencia de salida del Motor o Potencia de entrada a la bomba (W)"
	REAL PhydB03						" Potencia de salida de la bomba (W)"
	REAL SB03							" Potencia aparente (VAR)"
	REAL QB03							" Potencia reactiva"
	REAL DP03							" Diferencia de Presion (bar)"
	REAL Prout							" Presion de salida hacia la membrana (bar)"
	REAL DP01							" Diferencia de Presion de la bomba B01(bar)"
	REAL DP02							" Diferencia de Presion de la bomba B02(bar)"
	REAL PinitB01 						" Presion en la boquilla del tanque T1 (bar)"
	REAL PinitB02						" Presion en la boquilla del tanque clear (bar)"
	REAL qclear							"Flujo desde la bomba de limpieza (m3/seg)"
	REAL qdes							"Flujo desde la bomba de desplazamiento (m3/seg)"
	REAL Pdes							"Potencia activa de consumo de bomba B01 (W)"
	REAL Pclear							"Potencia activa de consumo de bomba B02 (W)"
	REAL Qdes							"Potencia reactiva de consumo de bomba B01 (var)"
	REAL Qclear							"Potencia reactiva de consumo de bomba B02 (var)"		
    	     
CONTINUOUS

	DP01=DPB01a.DP01
	DP02=CLB02a.DP02
	
	PinitB01=DPB01a.Pinit	    
	PinitB02=CLB02a.Pinit 
	
	qdes=DPB01a.q
	qclear=CLB02a.q
	
	Pdes=DPB01a.P 							-- Potencia activa de consumo B01 [W]
	Pclear=CLB02a.P
	
	Qdes=DPB01a.Q							-- Potencia reactiva de consumo B01 [var]
	Qclear=CLB02a.Q
	
	qnew=qclear+qdes							-- Caudal real fijado [m3/s]	
	q=qnew*3600									-- Caudal real fijado [m3/h]	
	
	hB03=787.7551-(69.2258*q)-(51.8667*(q**2))
			   
	PhydB03=ro*g*hB03*qnew                                              
	P2B03=PhydB03*100/EtaB03                                  
	P1B03=P2B03/(EtaMB03*3)                                    
	SB03=P1B03/cosphiB03                                      
	QB03=SB03*sin(acos(cosphiB03))    
	
	DP03=ZONE (qnew==0) 0
	     OTHERS ro*g*hB03/100000
	     
	Prout=ZONE (qnew==0) 0
	     OTHERS DP03+DP01+PinitB01+DP02+PinitB02    
	
	B03Memb.q=qnew       
	B03Memb.P=Prout                       
	
	Pcargagridb.Pact=P1B03+Pdes+Pclear
	Pcargagridb.Qreact=QB03+Qdes+Qclear                     
		
END COMPONENT

COMPONENT Tanque1
	"Tanque de almacenamiento de agua salada 'T1'"

PORTS

----------------------------------------------------------------------
-- Entradas: 
-- Flujo de entrada de la bomba B01
-- Flujo de salida de la bomba feed B04
----------------------------------------------------------------------

	IN B01Tanq1						B01Tanq1a
	IN B04Tanq1						B04Tanq1a

----------------------------------------------------------------------
-- Salidas: 
-- Altura del tanque 1
----------------------------------------------------------------------
	OUT Tanq1CH						Tanq1CHb
	OUT Tanq1B01					Tanq1B01b

DATA 

	REAL AreaT1=1.5						" Area del tanque 1 (m2)"
	REAL HmaxT1=3.5						" Atura del tanque mxima (m)"
	REAL HminT1=0.5						" Atura del tanque mnima (m)"
	
		
DECLS

	REAL HT1									" Altura del tanque 1 (m)"
	REAL qin									"Flujo de entrada de la bomba de alimentacion B04 (m3/seg)"
	REAL qout								"Flujo de salida de la bomba B01 (m3/seg)"
	
	

INIT

	HT1=2  
    	     
CONTINUOUS

	qout=B01Tanq1a.q
	qin=B04Tanq1a.q
	
	HT1'=(qin-qout)/AreaT1
	
	Tanq1CHb.HT1=HT1
	Tanq1B01b.HT1=HT1
		
END COMPONENT


COMPONENT TanqueClear
	"Tanque de almacenamiento de agua limpia a recircular 'TCL'"

PORTS

----------------------------------------------------------------------
-- Entradas: 
-- Flujo de entrada de la membrana
-- Flujo de salida de la bomba clear B02
----------------------------------------------------------------------

	IN B02Tanqcl						B02Tanqcla
	IN ValTCL						   ValTCLa

----------------------------------------------------------------------
-- Salidas: 
-- Altura del tanque de limpieza
----------------------------------------------------------------------


DATA 

	REAL AreaTcl=0.5						" Area del tanque 1 (m2)"
	REAL HmaxTcl=0.95						" Atura del tanque mxima (m)"
	REAL HminTcl=0.05						" Atura del tanque mnima (m)"
	
		
DECLS

	REAL HTcl								" Altura del tanque 1 (m)"
	REAL qin									"Flujo de entrada de la bomba de alimentacion B04 (m3/seg)"
	REAL qout								"Flujo de salida de la bomba B01 (m3/seg)"
	
	

INIT

	HTcl=0.95  
    	     
CONTINUOUS

	qout=B02Tanqcla.q
	qin=ValTCLa.q
	
	HTcl'=(qin-qout)/AreaTcl
		
END COMPONENT

COMPONENT Tanque2
	"Tanque de almacenamiento de agua totalmente desalada 'T2'"

PORTS  

----------------------------------------------------------------------
-- Entradas: 
-- Flujo proveniente de la valvula
-- Flujo proveniente del consumo del pueblo
----------------------------------------------------------------------

	IN ValT2								ValT2a
	IN SourceT2							SourceT2a
	
	
----------------------------------------------------------------------
-- Salidas: 
-- Altura del Tanque 2
----------------------------------------------------------------------

	OUT Tanq2CH							Tanq2CHb


DATA 

	REAL AreaT2=2							" Area del tanque 1 (m2)"
	REAL HmaxT2=2.95						" Atura del tanque mxima (m)"
	REAL HminT2=0.05						" Atura del tanque mnima (m)"
	
		
DECLS

	REAL HT2									" Altura del tanque 1 (m)"
	REAL qin									"Flujo de entrada de la bomba de alimentacion B04 (m3/seg)"
	REAL qout								"Flujo de salida de la bomba B01 (m3/seg)"
	
	

INIT

	HT2=1  
    	     
CONTINUOUS

	qin=ValT2a.q

	qout= ZONE ((HT2<=HminT2) AND (SourceT2a.q>qin)) qin
	      OTHERS SourceT2a.q
	
	HT2'=(qin-qout)/AreaT2
	
	Tanq2CHb.HT2=HT2
		
END COMPONENT


COMPONENT ControlHisteresis
	"Control de altura tanque agua salada"


PORTS

----------------------------------------------------------------------
-- Entradas: 
-- Altura del Tanque 1
----------------------------------------------------------------------

	IN Tanq1CH						Tanq1CHa
	
----------------------------------------------------------------------
-- Salida: 
-- Actuvacin de la bomba de alimentacin
----------------------------------------------------------------------

	OUT CHFeedB						CHFeedBb

DATA 

	REAL HmaxT1=3.5						" Atura del tanque mxima (m)"
	REAL HminT1=0.5						" Atura del tanque mnima (m)"
		
		
DECLS
	 
	 REAL nfeed				" Encendido la bomba de alimentacion"
	 REAL HT1				" Altura del tanque 1 (m)"
	 REAL aux				" Variable auxiliar"

INIT

	nfeed=0

DISCRETE

       WHEN (HT1>=HmaxT1)THEN  -- Limpiar
 				aux=0
       END WHEN
       
       WHEN (HT1<=HminT1)THEN  -- Limpiar
 				aux=1
       END WHEN    
    	     
CONTINUOUS

	HT1=Tanq1CHa.HT1
	
  	nfeed= ZONE (aux==0) 0
		    OTHERS 1
		    
	CHFeedBb.nfeed=nfeed	
		
END COMPONENT

COMPONENT ControlHist2
	"Control de altura tanque agua desalada"

PORTS

----------------------------------------------------------------------
-- Entradas: 
-- Altura del Tanque 2
----------------------------------------------------------------------

	IN Tanq2CH						Tanq2CHa
	
----------------------------------------------------------------------
-- Salida: 
-- Activacin de la bomba de desplazamiento y de limpieza
----------------------------------------------------------------------

	OUT CHB01						CHB01b

DATA 
  
	REAL HmaxT2=2.95						" Atura del tanque mxima (m)"
	REAL HminT2=0.05						" Atura del tanque mnima (m)"
		
		
DECLS
	 
	 REAL ndes				" Encendido la bomba de alimentacion"
	 REAL HT2				" Altura del tanque 1 (m)"
	 REAL aux				" Variable auxiliar"

INIT

	ndes=1

DISCRETE

       WHEN (HT2>=HmaxT2)THEN  -- Limpiar
 				aux=0
       END WHEN
       
       WHEN (HT2<2.4)THEN  -- Limpiar
 				aux=1
       END WHEN    
    	     
CONTINUOUS

	HT2=Tanq2CHa.HT2
	
  	ndes= ZONE (aux==0) 0
		   OTHERS 1
		    
	CHB01b.ndes=ndes
		
END COMPONENT



COMPONENT Valvula
	"Vlvula reguladora de caudal"


PORTS

------------------------------------------------------------------------------
-- Entrada: Flujo desde la membrana de osmosis inversa
------------------------------------------------------------------------------

		IN MemVal								MemVala


------------------------------------------------------------------------------
-- Salidas: 
-- Tanque de salida
-- Tanque de Limpieza
------------------------------------------------------------------------------

		OUT ValTCL								ValTCLb
		OUT ValT2								ValT2b

DATA 

	REAL tiempo=46800					" Hora en que se realiza la limpieza (seg)"
		
DECLS

		REAL nclean 					" Variable interna"
		REAL nfillCL					" Variable interna"
		REAL Qin							" Flujo de salida de la membrana (m3/seg)"
		REAL QCL							" Flujo hacia el tanque de limpieza (m3/seg)"
		REAL Qdes						" Flujo hacia el tanque 2 (m3/seg)"

	


INIT


DISCRETE

		 WHEN ((TIME>=tiempo) AND (TIME<(tiempo+810)))THEN  -- Limpiar
 				nclean=1 
 				nfillCL=0
       END WHEN
       
       WHEN ((TIME>=(tiempo+810)) AND (TIME<(tiempo+2066.6)))THEN  -- Limpiar
 				nclean=1 
 				nfillCL=1
       END WHEN
       
       WHEN ((TIME<tiempo) OR (TIME>=(tiempo+2066.6)))THEN   -- Solo se desalina
 				nclean=0
 				nfillCL=0
       END WHEN
  
    	     
CONTINUOUS

		Qin=MemVala.q
		
		
		QCL= ZONE (nfillCL==1) Qin 
			  OTHERS 0
			  
	   Qdes= ZONE (nclean==0) Qin 
			  OTHERS 0			  
			  
		
		ValTCLb.q=QCL
		
		ValT2b.q=Qdes
		
END COMPONENT



COMPONENT DataAgua
	"Flujo de agua desalada saliente de la desalinizadora"

PORTS

---------------------------------------------------------------------------
--Salida: Flujo de salida del agua
----------------------------------------------------------------------------
	OUT SourceT2				SourceT2b

           	
DATA
		TABLE_1D TabQwd= {{0,3600,7200,10800,14400,18000,21600,25200,28800,32400,36000,39600,43200,46800,50400,54000,57600,61200,
   64800,68400,72000,75600,79200,82800},  
	{0.46,0.68,0.35,0.67,0.36,0.53,0.69,0.75,1.52,1.64,1.41,1.87,1.82,1.67,1.68,1.87,1.52,1.17,0.36,0.36,0.36,0.36,0.36,0.36}}   "Datos de consumo de agua"
	
		REAL Ti=100							"Constante de tiempo del sensor de velocidad"
						
DECLS

   
	--1.54,1.19,1.61,1.34,1.35,1.32
	REAL Qwde
	REAL Qwda



INIT

 	Qwde=0.46/3600
      
CONTINUOUS

   Qwda=timeTableStep(TIME,TabQwd)/3600
   
   -- ************  Definicion del sensor de velocidad *******************	

	Ti*Qwde'=Qwda-Qwde
	
	SourceT2b.q=Qwde


END COMPONENT
