USE MATH

-- Fecha de Actualizacion: 17/08/2010



--******************************************************************************
--                        MODELO DE PREDICCION PARA LA RADIACION SOLAR
--											Listo ya funciona
--******************************************************************************

COMPONENT SOlarRadiation
	"Modelo de prediccin de radiacin solar"

-- NOTA 1
-- Ecosimpro trabaja en radianes

-- NOTA 2
-- Por el momento se tiene una fuente de un dia, se tiene planificado
-- aumentar el rango de la fuente cuando se haya verificado que el modelo
-- funciona bien para un dia

-- NOTA 3
-- La escala de tiempo es hora

-- NOTA 4
-- Se tiene la fuente para un dia fijo despues se piensa hacer variable

-- NOTA 5
-- Se compara la radiacion real con la radiacion modelada para el 18 de Agosto

-- NOTA 6
-- Se va a incluir el efecto de las nubes. Se considera una perdida maxima de 15%.
-- Provisionalmente este efectos de las nubes seran un numero aleatorio que oscile
-- entre 0 a 15% de perdida.

PORTS

DATA

TABLE_1D tabIb= { {0,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22},    -- time values
                  {0,21.15,192.73,374.13,519.53,616.23,741,822.38,848.03,835.67,745.82,599.5,425.92,237.32,68.1,19.87,38.95,10.58,0.3 } }    
  
-- Datas del Area

	REAL Lat=36.698				" Latitud (degree)"
	REAL Lon=10.395				" Longitud (degree)"

-- Por el momento la mantendremos fija

	REAL dia=18						" Today "
	REAL month=8					" January=1 (month)"
	REAL year=2010					" Year "
	REAL Gc=7117.21				" Montly average value of total daily irradiation"	


DECLS
         
	                                          
   INTEGER i_array[5]         "Auxiliar array of integers (-)"
   REAL z_array[100]    		"Auxiliar array (-)"    
   INTEGER i_arrayb[5]        "Auxiliar array of integers (-)"
   REAL z_arrayb[100]    		"Auxiliar array (-)"         
	REAL day							" Today "
	REAL LeapYear					" Ano Bisiesto"
	REAL N							" number for the day of the month"
	EXPL REAL phi					" Solar declination (degree)"
	EXPL REAL Et					" Time equation (hora)"
	EXPL REAL GMTsunset			" Sunset hours of the day (hora)"
	EXPL REAL GMTsunrise 		" Sunrise hours of the day (hora)"
	EXPL REAL DeltaT				" Day length (hora)"	
	EXPL REAL Irradiation		" Daily irraciation estimated from sunrise to sunset"
	REAL Irradiationb				" Radiacion solar real para el dia indicado"
	REAL Irradiationc				" Radiacion solar con caracter aleatorio"
	REAL x							" Senal aleatoria para la amplitud"
	REAL tstop						" Senal de cambio de eventos"
	REAL dt							"Time between samples (s)"
		
		 		
INIT

-- Initializes sampling

      tstop=0
      
-- These flags are always needed
      i_array[4] = 1200
      i_array[5] = 0
      i_arrayb[4] = 1200
      i_arrayb[5] = 0

	      
CONTINUOUS

      Irradiationb = timeTableInterp(TIME, tabIb)

	SEQUENTIAL
	
-- Buscar si el ano es bisiesto o no
   
   	IF ((remainder(year,4)==0)AND ((remainder(year,100)!=0) OR (remainder(year,400)==0))) THEN
   	
   	LeapYear=1
   	
   	ELSE 
   	
   	LeapYear=0
   	
   	END IF
   	
 -- Cantidad de dias dependiendo del mes al cual hacemos referencia
 
 		IF (month==1) THEN day=dia
 		ELSEIF (month==2) THEN day=31+dia
 		ELSEIF (month==3) THEN day=59+dia+LeapYear
 		ELSEIF (month==4) THEN day=90+dia+LeapYear
 		ELSEIF (month==5) THEN day=120+dia+LeapYear
 		ELSEIF (month==6) THEN day=151+dia+LeapYear
 		ELSEIF (month==7) THEN day=181+dia+LeapYear
 		ELSEIF (month==8) THEN day=212+dia+LeapYear
 		ELSEIF (month==9) THEN day=243+dia+LeapYear
 		ELSEIF (month==10) THEN day=273+dia+LeapYear
 		ELSEIF (month==11) THEN day=304+dia+LeapYear
 		ELSEIF (month==12) THEN day=334+dia+LeapYear
 		END IF
 		
-- Reflejo de la cantidad de dias sobre 360
	
		IF (LeapYear==1) THEN
   	
   	N=day*360/366
   	
   	ELSE 
   	
   	N=day*360/365
   	
   	END IF	

		phi=23.5*cos(2*PI*(N+10)/360)
				
		Et=0.123*cos(2*PI*(N+87)/360)-(sin(2*PI*(2*(N+10))/360)/6)
		
		GMTsunset=12-Et+((1/15)*(Lon+(360*acos(tan(2*PI*phi/360)*tan(2*PI*Lat/360))/(2*PI))))
		
		GMTsunrise=12-Et+((1/15)*(Lon-(360*acos(tan(2*PI*phi/360)*tan(2*PI*Lat/360))/(2*PI))))
		
 		DeltaT=GMTsunset-GMTsunrise
 
 -------------------------------------------------------------------------			
 	-- Variacion de la nube
-------------------------------------------------------------------------

 		IF (TIME>tstop) THEN
 		dt=0.5+(2.5*ran1(i_arrayb, z_arrayb))
   	x=0.20*ran1(i_array, z_array)
   	tstop=TIME+dt
   	END IF 
 		 
  			 	 
	END SEQUENTIAL
	
		Irradiation= ZONE(TIME>GMTsunset) 0
 						 ZONE (TIME<GMTsunrise)0
 						 OTHERS PI*Gc*sin(PI*(TIME-GMTsunrise)/DeltaT)/(2*DeltaT)
 	
 		Irradiationc=(1-x)*Irradiation

 				
 -- Cosas que faltan
 
 -- A) Incluir mas dias en forma automatica
 -- b) Cargar los G para cada dia del ano
 -- c) Cambiar la escala dependiendo de los restantes modelos		 
 						 
	 	
END COMPONENT


--******************************************************************************
--           MODELO PARA LA TEMPERATURA EN LOS PANELES SOLARES
--******************************************************************************

COMPONENT SOlarTemperatura
	"Modelo para la temperatura de los paneles solares. Sin desarrollar."
PORTS

DATA

DECLS
			 		
INIT
	      
CONTINUOUS
 
END COMPONENT

