COMPONENT membrana
	"Membrana para filtrado de agua salada"

PORTS

-----------------------------------------------------------------------------------
-- Entradas Presion y el flujo
------------------------------------------------------------------------------------
		IN B03Mem						B03Mema
		
------------------------------------------------------------------------------
-- Salidas: Flujo desde la membrana de osmosis inversa a la valvula
------------------------------------------------------------------------------

		OUT MemVal								MemValb


DATA

	REAL A=0.2                   " Parametro de Permeabilidad del agua (m3/hbar)"
	REAL B=0.01                  " Parametro de Permeabilidad de la sal (m3/hbar)"
	INTEGER n=5						  " Discretizacion de la membrana"
	REAL area=0.0750				  " Area en la boquilla de la membrana (m)"
	REAL Vi=0.03					  " Volumen concentrado en cada discretizacion (m3)"
	REAL kpd=1.3					  " Diferencia de presion"
	REAL feedC=18					  " Concentracin de alimentacion (kg/m3)"
	REAL feedT=20					  " Temperatura de alimentacion (C)"
	REAL P_permeate=1.5			  " Presion de Permeado (bar)"	
	REAL ro=1000                 " Densidad del agua (kg/m3)"
	
DECLS
	
	REAL CSalt[5]             			" Concentracin de sal (kg/m3)"
	REAL Wd[6]								" Flujo directo en cada discretizacion (kg/s)"
	REAL Qin				        		   " Flujo de entrada a la membrana de Osmosis Inversa (m3/seg)"
	REAL feedP					  			" Presion de alimentacin a la membrana (bar)"
	
	EXPL REAL Jw[5]						" Flujo de la masa de agua a travs de la membrana (kg/s)"
	EXPL REAL Jw_sum						" Flujo total de la masa de agua a travs de la membrana (kg/s)"
	EXPL REAL Js[5]						" Flujo de la masa de sal a travs de la membrana (kg/s)"	
	EXPL REAL Js_sum						" Flujo total de la masa de sal a travs de la membrana (kg/s)"
	
	REAL Cin[5]								" Concentracion de sal de entrada (kg/m3)"
	REAL pi[5]								" Presion Osmotica (bar)"
	
	REAL pd									" cada de presin (bar)"
	REAL C_permeate						" Concentracion de sal en el permeado (kg/m3)"
	EXPL REAL P[5]							" Presion del concentrado o rechazo (bar)"
	EXPL REAL P_retentate				" Presion del concentrado o rechazo (bar)"
	EXPL REAL Q_retentate				" Flujo del concentrado o rechazo (m3/s)"
	EXPL REAL Q_permeate					" Flujo del permeado (m3/seg)"

INIT

	FOR(i IN 1,n)
	
		CSalt[i]=0
		
	END FOR

CONTINUOUS

	Qin=B03Mema.q
	feedP=B03Mema.P


	-- Concentracin de entrada
				
	EXPAND_BLOCK(i IN 2,5)
		Cin[i] = CSalt[i-1]
	END EXPAND_BLOCK	
		Cin[1] = feedC
				
	
	-- balance de masa
		
	EXPAND_BLOCK(i IN 1,5)
	
		Vi*CSalt[i]' = (Wd[i]*Cin[i]) - (Wd[i+1]*CSalt[i])- (ro*Js[i])
	
	END EXPAND_BLOCK
	
	
	-- Presion Osmotica
	
	EXPAND_BLOCK(i IN 1,5)
	
		pi[i] = 3E-3*(feedT+273)*f_max((CSalt[i]-C_permeate),0)
	
	END EXPAND_BLOCK
		
	-- Flujo de agua a travs de la membrana
	
	EXPAND_BLOCK(i IN 1,5)
		Jw[i] = f_max(A*0.07*(1/3600)*(P[i] - P_permeate - pi[i]),0)
	END EXPAND_BLOCK

	Jw_sum =f_max((SUM(i IN 1,5; Jw[i])),0.0000001)
	
	-- Flujo de masa concentrado o rechazo
	
	EXPAND_BLOCK(i IN 2,6)
   Wd[i] = f_max((Wd[i-1] - Jw[i-1]),0)
	END EXPAND_BLOCK
	
	Wd[1] = f_max(Qin,0)
	
	-- Flujo de sal a travs de la membrana
	
	EXPAND_BLOCK(i IN 1,5)
		Js[i] = B*0.001*(1/3600)*f_max((CSalt[i] - C_permeate),0)
	END EXPAND_BLOCK	
	
	Js_sum = SUM(i IN 1,5; Js[i])
	
	-- Caida de presion
	
	   pd = kpd*(Wd[1]**0.5)
	
	-- Presion del concentrado

	EXPAND_BLOCK(i IN 1,5)
		P[i] = (feedP - (pd*i/6))
	END EXPAND_BLOCK
	
	
	-- Concentracion del permeado
	
	C_permeate =ro*(Js_sum/Jw_sum)
	
	-- Flujo de permeado
	
	Q_permeate=Jw_sum
	
	-- Presion del concentrado
	
	P_retentate=feedP-pd
	
	-- Flujo del concentrado
	
	Q_retentate=Wd[6]
	
	MemValb.q=Q_permeate		

END COMPONENT
