USE MATH

COMPONENT Solar

PORTS

   	IN PVSBV  		pvsbva    -- Voltaje es de entrada fijado por el SB
   	OUT PVSBI  		pvsbia    -- Corriente resultante del modulo
     	
DATA


//TABLE_1D Tabfac = {{0.5,1.5,2.5,3.5,4.5,5, 5.5, 6, 6.5,7}, {50, 51.5, 52, 53, 58,53, 52, 51.5, 50,49}}
	

-- Module Used: Wuxi Green Energy Source - 185Wp
	
	REAL Vocmstc=44.8 		" Open Circuit voltage - Module (Volts)"
	REAL Iscmstc=5.51			" Short Circuit current - Module (Amps)"
	REAL NOCT=46				" Normal operating cell temperature (C)"
	REAL Vmpmstc=36.2			" Voltage at maximum power - Module (Volts)"
	REAL Impmstc=5.11			" Current at maximum power - Module (Amps)"
	REAL Pmaxmstc=185 		" Maximun Power - Module (Wp)"
	REAL Tref=25				" Reference temperature  (C)"
	REAL Gstc=1000				" Standard solar radiation (w/m2)"
	REAL Efficiency=14.6		" Modules efficiency (%)"
	REAL Beta=-0.38			" Sensitivity of Open Circuit voltage to temperature (%/C)"
	REAL Alfa=0.10				" Sensitivity of Short Circuit current to temperature (%/C)"
	REAL Gamma=-0.47			" Sensitivity of Maximun Power to temperature (%/C)"
	REAL Surface = 1.277 	" Module surface (m2)"
	REAL Nsc=12					" Number of serial cells in one module"
	REAL Npc=6 					" Number of parallel cells in one module"
		
-- Datos Suministrado por el diseo del Arreglo Fotovoltaico
	
	INTEGER Npm = 2			" Number of modules in parallel"
	INTEGER Nsm = 14			" Number of modules in series"
	
	
-- Constantes

	REAL vt = 0.0248			" Thermal voltage (volts)"

-- Valores Geogrficos
	
	REAL G=1000					" Solar radiation (w/m2)"
--	REAL Tenv=0 				" Environment temperature (C)"

-- Entradas del Sunny Boy
	
/*	REAL nsb=0.96
	
	REAL k4=10						"Constante auxiliar"   --REVISAR
   REAL k2=5						"Constante auxiliar"   --REVISAR*/
   
   
DECLS

   TABLE_1D tabT= {{0.,1000,2000,3000,4000,5000,6000,7000,8000,9000}, {25,-30,25,10,0,0,10,25,100,25}}
   		
   		--  {0.,1000,2000,3000,4000,5000,6000,7000,8000,9000}, {25,-30,25,10,0,0,10,25,100,25}
   		-- {0.,1000,2000,3000,4000,5000,6000,7000,8000,9000}, {40,20,-10,-30,-40,-50,0,10,0,5}
   		
	EXPL REAL Tcell				" Cell temperature  (C)"
	EXPL REAL Vocg 				" Open circuit voltaje - Array (Volts)"
	EXPL REAL Iscg 				" Short circuit current - Array (Amps)"
	EXPL REAL Voc					" Open Circuit Voltage of a cell (Volts)"	
	EXPL REAL Vocn				   " Open Circuit Voltage of a cell normalizado"	
	EXPL REAL Isc					" Short Circuit Current of a cell (Amps)"	
	EXPL REAL Pmax				   " Maximum Power of a cell (Wp)"	
	EXPL REAL FF					" Factor de Forma STC para una celda solar"	
	EXPL REAL FFo					" Factor de Forma STC para una celda ideal"	
	EXPL REAL rs					" Series resistance of a cell normalizada"	
	EXPL REAL Rsm					" Series resistance of a module (Ohms)"	
	EXPL REAL Rsg					" Series resistance - array (Ohms)"
	EXPL REAL Vdcpv
	REAL Idcpv
	REAL I
	REAL Tenv
	

		

INIT
    	     
CONTINUOUS

  Tenv=timeTableStep(TIME, tabT) 
 
	-------------------- Calcular Resistencia en serie de un arreglo solar-------------------------

-- a) Caractersticas de una celda solar:
		Voc=Vocmstc/Nsc
		Vocn=Voc/vt
		Isc=Iscmstc/Npc
		Pmax=Pmaxmstc/(Npc*Nsc)
	
-- b) Factor de Forma STC para una celda solar:
		FF=Pmax/(Isc*Voc)					
		
-- c) Factor de forma para una celda ideal sin considerar la resistencia serie:
		FFo=(Vocn-log(Vocn+0.72))/(Vocn+1)
		
-- d) Resistencia en serie de una celda solar normalizada:
		rs =1-(FF/FFo)					

-- e) Resistencia en serie de un modulo solar:
		Rsm=rs*Vocmstc/Iscmstc    	

-- f) Resistencia en serie de un arreglo solar:		
		Rsg=Rsm*Nsm/Npm 

	-- Temperatura de Trabajo
	
	Tcell=Tenv+(G*(NOCT-20)/800)
	
	-- Voltaje a circuito abierto 	
			
	Vocg=Nsm*Vocmstc*(1+ (Beta*(Tcell-Tref)/100))
	
	-- Corriente a Corto Circuito 
	
	Iscg= Npm*Iscmstc * G * (1 + (Alfa*(Tcell - Tref)/100))/ Gstc 
	   	
	-- Calculo la corriente considerando el voltaje impuesto por el inversor
	
	Vdcpv=pvsbva.Vdc
	
	-- Limitacion del voltaje de entrada, no puede ser mayor al VOC
	   
   Idcpv=Iscg*(1-exp((Vdcpv+Rsg*Idcpv-Vocg)/(vt*Nsm*Nsc)))

	pvsbia.Idc=Idcpv
	
	

END COMPONENT


--------------------------------------------------------------------------------
--                       COMPONENTE DEL SUNNY BOY
--------------------------------------------------------------------------------

	COMPONENT SUNNYBOY  
   
	PORTS
  	
  	-- Relacion Paneles Solares- Sunny Boy
  	
   	OUT PVSBV  		pvsbva     -- el voltaje que el sb le fija al arreglo solar
   	IN PVSBI  		pvsbia     -- Corriente resultante del arreglo solar
   
   -- Relacion Sunny Boy - Sunny Island	
   	
   	IN SBSIV       sbsiva	-- el voltaje que el si le fija al subsistema solar
   	OUT SBSII		sbsiia	-- La corriente resultante del arreglo solar
   	
	DATA
	
   
	DECLS   	
	
	REAL fac
	REAL effSB
   REAL Vref						       "Voltaje de Referencia"
	EXPL REAL deltaV
	EXPL REAL deltaVb
	EXPL REAL Idcpv
	EXPL REAL Psb							"Potencia del Sunny Boy"
	EXPL REAL Psbant						"Potencia anterior del Sunny Boy"
	EXPL REAL Pscant
	EXPL REAL Vrefant
	REAL Idcpvant
	REAL PotLim
	REAL Potref
	REAL Vrefa
	EXPL REAL ninv
	EXPL REAL Pinv
	EXPL REAL Vpinv
	EXPL REAL Ipinv
	

	INIT
	 
	Vref=246
	
	deltaV=1
	
	deltaVb=1
	
	DISCRETE

       WHEN (effSB!=1)THEN
 				Potref=Psb --100000--Psb 
       END WHEN
       
       WHEN (effSB==1)THEN
 				Potref=20000  
       END WHEN
       
	
   CONTINUOUS 
     
  ------------------------------------------------------------------
  --  Seguimiento del Punto de Maxima Potencia
  ------------------------------------------------------------------

  
 Idcpv=pvsbia.Idc
 
 fac=sbsiva.fac
 
 Idcpvant= delay(Idcpv,0.5)
 
 SEQUENTIAL
 
   
		 Psb=Idcpv*Vref
		 
		 Psbant=delay(Psb,0.5)      -- potencia con un retraso de 0.1
		 
		 Pscant=delay(Psb,1)      -- potencia con un retraso de 0.2
		 	 		 
		 deltaVb=delay(deltaV,0.5)  -- delta con un retraso de 0.1
		 
		 Vrefant=delay(Vref,0.2)
		 
		 IF((fac>=45.5) AND (fac<=51)) THEN
		 			 
		 			 effSB=1
		 			 
		 			 ELSEIF ((fac>51) AND (fac<=52)) THEN
		 			 effSB=-fac+52
		 			 
		 			 ELSE 
		 			 effSB=0     -- se tiene que apagar el sunny island	
		 			 
		  END IF
	
	
		  PotLim=effSB*Potref
	
		 
		 -- Determinar valores de la pendiente
		 	 	 	  
				 -- Caso a =  Estoy aumentando el voltaje, la potencia aumenta, el voltaje es menor a 475, la potencia no esta limitada
				 -- Accin: continuo aumentando el voltaje
										
					 IF((deltaVb==1) AND ((Psb-Psbant)>0.5) AND ((Psbant-Pscant)>0.5) AND (Vref<475) AND ((Psb-PotLim)<-0.5)) THEN
		 			 deltaV=1  
		 			 
		 		 -- Caso b =  Estoy disminuyendo el voltaje, la potencia aumenta, el voltaje es mayor a 248, la potencia no esta limitada
				 -- Accin: continuo disminuyendo el voltaje
				 
		 	  		 ELSEIF ((deltaVb==-1) AND ((Psb-Psbant)>0.5) AND ((Psbant-Pscant)>0.5)  AND ((Psb-PotLim)<-0.5)) THEN
					 deltaV=-1
					 
				 -- Caso c =  Estoy disminuyendo el voltaje, la potencia disminuye, el voltaje es menor a 475, la potencia no esta limitada
				 -- Accin: Voy a aumentar el voltaje
					
					 ELSEIF ((deltaVb==-1) AND ((Psb-Psbant)<-0.5) AND ((Psb-Pscant)<-0.5) AND (Vref<475) AND ((Psb-PotLim)<-0.5)) THEN
					 deltaV=1
					 
				 -- Caso d =  Estoy aumentando el voltaje, la potencia disminuye, el voltaje es mayor a 248, la potencia no esta limitada
				 -- Accin: Voy a disminuir el voltaje
				 
					 ELSEIF ((deltaVb==1)  AND ((Psb-Psbant)<-0.5) AND ((Psb-Pscant)<-0.5) AND ((Psb-PotLim)<-0.5))  THEN
					 deltaV=-1
				 
				 -- Caso e= delta es distinto de cero, el voltaje varia poco, la potencia y la corriente varia poco, Vref esta entre 248 y 475, la potencia no esta limitada
				 -- Accion= Se fija delta en cero			 
					  		 
					 ELSEIF ((deltaV!=0) AND (deltaVb!=0) AND (Vref-Vrefant<=0.5) AND (Vref-Vrefant>=-0.5) AND (Psb-Psbant>=-0.5) AND (Psb-Psbant<=0.5) AND (Psbant-Pscant>=-0.5) AND (Psbant-Pscant<=0.5) AND (((Idcpv-Idcpvant)>-0.5) AND ((Idcpv-Idcpvant)<0.5))AND (Vref>248) AND (Vrefant>248) AND (Vref<475) AND ((Psb-PotLim)<-0.5))  THEN
					 deltaV=0
					 
				 -- Caso f= Delta esta fijado en 0, la potencia varia, la radiacion solar o G varia, el voltaje no esta en el limite, y no se tiene limitada la potencia, el voltaje est entre 475 y 248, la potencia no esta limitada
				 -- Accion= Se fija delta en uno (cualquier cosa)
					 
					 ELSEIF ((deltaV==0) AND (deltaVb==0) AND  (((Psb-Psbant)<-0.5) OR  ((Psb-Psbant)>0.5) OR ((Psb-Pscant)<-0.5) OR ((Psbant-Pscant)>0.5)) AND (((Idcpv-Idcpvant)<-0.5) OR ((Idcpv-Idcpvant)>0.5)) AND (Vref<475) AND (Vref>248) AND ((Psb-PotLim)<-0.5)) THEN  
					 deltaV=1		
				
				 -- Caso g= Delta esta fijado en 0, la potencia varia, la radiacion solar o G varia, el voltaje esta en el limite 480, y no se tiene limitada la potencia
				 -- Accion= Se fija delta en -1
				 
				 	 ELSEIF ( (deltaV==0)AND (deltaVb==0) AND(((Psb-Psbant)<-0.5) OR ((Psb-Psbant)>0.5) OR ((Psb-Pscant)<-0.5) OR ((Psbant-Pscant)>0.5)) AND (((Idcpv-Idcpvant)<-0.5) OR ((Idcpv-Idcpvant)>0.5)) AND (Vref<485) AND (Vref>=475) AND ((Psb-PotLim)<-0.5))  THEN
					 deltaV=-1
					 
				 -- Caso h= Delta esta fijado en 0, la potencia varia, la radiacion solar o G varia, el voltaje esta en el limite 246, y no se tiene limitada la potencia
				 -- Accion= Se fija delta en 1
					 
					 ELSEIF ((deltaV==0) AND (deltaVb==0) AND (((Psb-Psbant)<-0.5) OR  ((Psb-Psbant)>0.5) OR ((Psb-Pscant)<-0.5) OR ((Psbant-Pscant)>0.5))  AND (((Idcpv-Idcpvant)<-0.5) OR ((Idcpv-Idcpvant)>0.5)) AND (Vref==246) AND ((Psb-PotLim)<-0.5))  THEN  
					 deltaV=1
					 
					 ELSEIF ((deltaV==0) AND (deltaVb==0) AND (TIME>500) AND ((Psb-Psbant)==0) AND ((Psbant-Pscant)==0)  AND ((Idcpv-Idcpvant)==0) AND (Vref==246) AND ((Psb-PotLim)<-0.5))  THEN  
					 deltaV=0	
					 
					 ELSEIF ((deltaV==0) AND (deltaVb==0) AND ((Psb-Psbant)==0) AND ((Psbant-Pscant)==0)  AND ((Idcpv-Idcpvant)==0) AND (Vref==480) AND ((Psb-PotLim)<-0.5))  THEN  
					 deltaV=0					
							
				-- Caso k= Si el voltaje es mayor a 480, deltaV=1, no hay limite de potencia
				-- Accin: Se fija delta en 0
					 				 
					 ELSEIF ((Vref>=480) AND (deltaV==1) AND (deltaVb==1) AND ((Psb-PotLim)<-0.5)) THEN  
					 deltaV=0

				
				-- Caso l= Si el voltaje es menor a 246, deltaV=-1, no hay limite de potencia
				-- Accin: Se fija delta en 0
					 
					 ELSEIF ((Vref<=246) AND (Vref<=248) AND (deltaV==-1) AND (deltaVb==-1) AND ((Psb-PotLim)<-0.5)) THEN  
					 deltaV=0
					 
		  ------------------------------------------------------------------
		  --  Limitacion de Potencia
		  ------------------------------------------------------------------	
						 
				-- Caso f = La potencia es igual a la potencia limite
				-- Accin: no cambio el voltaje
					 
					ELSEIF ((Psb-PotLim>=-0.5) AND ((Psb-PotLim)<=0.3)) THEN
					deltaV=0
				
				-- Caso x= Tengo el voltaje constante, pero la potencia es mayor a la potencia limite
				-- Accin: Cambio el delta del voltaje
					 
				   ELSEIF ((deltaV==0) AND (deltaVb==0) AND (Vref<485) AND (Vref>=475) AND ((Psb-PotLim)>0.3)) THEN
				   deltaV=-1
				   
				   ELSEIF ((deltaV==0) AND (deltaVb==0) AND ((Idcpv-Idcpvant)==0) AND (Psb==Psbant) AND (Psbant==Pscant) AND (Vref<475) AND ((Psb-PotLim)>0.3)) THEN
				   deltaV=-1
				   
				   ELSEIF ((deltaV==0) AND (deltaVb==0) AND (((Psb-Psbant)<-0.5) OR  ((Psb-Psbant)>0.5) OR ((Psb-Pscant)<-0.5) OR ((Psbant-Pscant)>0.5)) AND ((Idcpv-Idcpvant)!=0) AND (Vref<475) AND ((Psb-PotLim)>0.3)) THEN
				   deltaV=-1   
				   
				   ELSEIF ((deltaV==0) AND (deltaVb==0) AND ((Idcpv-Idcpvant)==0) AND (Psb==Psbant) AND (Psbant==Pscant) AND (Vref<475) AND ((Psb-PotLim)<-0.5)) THEN
				   deltaV=1
						 
				 -- Caso g =  Estoy disminuyendo el voltaje, la potencia disminuye, lo deseo ya que la potencia es mayor a la potencia limite
				 -- Accin: Voy a disminuir el voltaje
					
					ELSEIF ((deltaVb==-1) AND ((Psb-PotLim)>0.3)) THEN
					deltaV=-1
					
					ELSEIF ((deltaVb==1) AND ((Psb-PotLim)>0.3)) THEN
					deltaV=-1
					 					 
					 		 		
				   END IF
					 
	 			
 END SEQUENTIAL
 
 Vrefa'=deltaV
  
 Vref=  ZONE (Vrefa>480) 480
        ZONE ((Vrefa<246) AND (Potref==20000)) 246
        OTHERS Vrefa
  
 pvsbva.Vdc=Vref
 
  ------------------------------------------------------------------
  --  Salida del Sunny Boy al Sunny Island
  ------------------------------------------------------------------
  
  
  			-- Calculo de la Potencia a la salida del inversor 

  			ninv=0.96  -- Falta el modelo para la eficiencia del sunny boy
      
   		Pinv=ninv*Psb 
   		   	   		
			-- Calculo de la corriente pico de la salida del inversor 
			
			Vpinv=sbsiva.Vmb
         				
			Ipinv=(2*Pinv)/(3*Vpinv)	
			
			sbsiia.Imb=Ipinv
			
/*			  
  a) RESOLVER EL CASO DE CORRIENTE NEGATIVA
  b) FALTA EL MODELO PARA LA EFICIENCIA
  c) LOS SALTOS EN LA CORRIENTE RMS QUE SE ENTREGA A LA RED. LA RED NO VE ESOS SALTOS
  d) COMIENZO PARA FIJAR VREF
  e) PROBLEMA CON UNA OSCILACION
  
  */

/* Una corrida revisar particion no estaba I y adems revisar*/  
          
          
 END COMPONENT		
			

		
