USE MATH

COMPONENT InversorTurbina
	"Inversor turbina elica CA/CA"

-- Como hemos considerador los equipo de SMA, en este caso hemos seleecionador el WindyBoy
-- el inversor recibe la potencia de la turbina de viento y recibe la seal de limitacion
-- del inversor de baterias... 
-- En caso de haber excesos de potencia, esa potencia en exceso es redirigida hacia una resistencia
-- de manera que el exceso de energia se transforma en calor y se pierde.

PORTS

----------------------------------------------------------------------------
-- Entradas: Pturbina, fgrid
----------------------------------------------------------------------------
		
		IN PotPuertos                 PotPuertosa 
		IN WBSIV								WBSIVa

----------------------------------------------------------------------------
-- salidas: Pgridturbina
----------------------------------------------------------------------------

//    OUT PgridFuente							PgridFuentea
		OUT InvAlt							InvAlta

DATA

	REAL kp=1000							"Constante del controlador de corriente PI"
	REAL ki=10000						   "Constante del controlador de corriente PI"
	REAL fgridop=50						"Frecuencia fundamental de red (Hz)"

DECLS

	REAL Pturbina							"Potencia que entrega la turbina de viento (W)"
	REAL fgrid								"Frecuencia definida por el inversor de baterias (Hz)"
	REAL PotTur								"Potencia que genera el subsistema solar considerando la limitacion del inversor de baterias (W)"
	REAL Paux								"Variable auxiliar de la potencia (W)"
	REAL Ptotal								"Variable auxiliar de la potencia (W)"
	REAL Pexceso							"Potencia desperdiciada en la resistencia de carga (W)"
	REAL Pexa								"Auxiliar del controlador de frecuencia"
	REAL Pexb								"Auxiliar del controlador de frecuencia"
	REAL error
	
INIT

	Pexb=0

CONTINUOUS

	Pturbina=PotPuertosa.Pmech
	fgrid=WBSIVa.fac
	
	-- Potencia minima que se necesita a la entrada del inversor para que pueda funcionar
	
	Paux=ZONE (Pturbina<218.303) 0
	  	  OTHERS Pturbina
	
	-- La eficiencia del inversor
	  	  
	Ptotal=0.952*Paux
		
	error=fgridop-fgrid
	
	Pexa=ZONE ((error>0) AND (Pexb>=0)) 0
	  	   OTHERS kp*error
  
   Pexb'=ZONE ((ki*error>0) AND Pexb>=0) 0
         OTHERS ki*error
		
	Pexceso=Pexb+Pexa
		
	PotTur=ZONE((Ptotal+Pexceso<=0) AND (Pexceso<0)) 0
	  	    OTHERS Ptotal+Pexceso

	InvAlta.Pact=PotTur
	
END COMPONENT


COMPONENT InversorSolar
	"Inversor paneles solares CC/CA"

-- Como hemos considerador los equipo de SMA, en este caso hemos seleecionador el WindyBoy
-- el inversor recibe la potencia de la turbina de viento y recibe la seal de limitacion
-- del inversor de baterias... 
-- En caso de haber excesos de potencia, esa potencia en exceso es redirigida hacia una resistencia
-- de manera que el exceso de energia se transforma en calor y se pierde.

PORTS

----------------------------------------------------------------------------
-- Entradas: PSolarMPPT, fgrid, Iscg
----------------------------------------------------------------------------
		
//		IN MPPTOpt							MPPTOptb
		IN SBSIV								SBSIVa

		IN SolInv							SolInvb		
----------------------------------------------------------------------------
-- salidas: Voltaje de referencia que va hacia el Boost Circuit
----------------------------------------------------------------------------

//		OUT MPPTOpt							MPPTOptd
		
		OUT InvAlt							InvAlta

DATA

	REAL kp=1000							"Constante del controlador de corriente PI"
	REAL ki=10000						   "Constante del controlador de corriente PI"
	REAL fgridop=50						"Frecuencia fundamental de red (Hz)"
	--REAL Ugridop=230

DECLS

	REAL Vop									"Voltaje de referencia del seguidor de mxima potencia (Volt)"
	REAL Iscg								"Corriente a corto circuito del arreglo solar (Amp)"
	REAL Pmax								"Potencia mxima segun el MPPT (W)"
	REAL fgrid								"Frecuencia definida por el inversor de baterias (Hz)"
	REAL Ptotal								"Variable auxiliar de la potencia (W)"
	REAL Pexceso							"Potencia desperdiciada en la resistencia de carga (W)"
	REAL Pexa								"Auxiliar del controlador de frecuencia"
	REAL Pexb								"Auxiliar del controlador de frecuencia"
	REAL error								"Error que se considera en el controlador PI (Hz)"
	REAL VoltSolar							"Voltaje que genera el subsistema solar considerando la limitacion del inversor de baterias (W)"
	REAL Imax
	REAL Psalida
	
	REAL Ugrid
	REAL cosfi
	REAL I
	/*
	
	REAL Paux								"Variable auxiliar de la potencia (W)"
	*/
	
INIT

	Pexb=0

CONTINUOUS

	Vop=SolInvb.Vmax
	Iscg=SolInvb.Iscg
	Pmax=SolInvb.Pact
	Imax=SolInvb.Imax
	
	fgrid=SBSIVa.fac
	Ugrid=SBSIVa.Vmb
	
	cosfi=SBSIVa.cosfi
	I=SBSIVa.I

	
	
	error=fgridop-fgrid
	
	Pexa= ZONE ((error>0) AND (Pexb>=0)) 0  	   
	  	   OTHERS kp*error
  
   Pexb'= ZONE ((ki*error>0) AND (Pexb>=0)) 0 
   		 ZONE (Pmax<=((Pexceso*-1)+0.0001)) 0
          OTHERS ki*error
		
	Pexceso=Pexb+Pexa
	
	Ptotal=Pmax+Pexceso
	
	VoltSolar=ZONE(Ptotal<=0.0001) Vop
	          OTHERS Ptotal/Iscg
	
	Psalida=Imax*VoltSolar
	
	--Psalida*0.972=Ugrid*I*cosfi
	
	InvAlta.Vmax=VoltSolar
	InvAlta.Imax=Imax
	InvAlta.Pact=Psalida
	
	
	/*
	
	-- Potencia minima que se necesita a la entrada del inversor para que pueda funcionar
	
		
	error=fgridop-fgrid
	
	Pexa=ZONE ((error>0) AND (Pexb>=0)) 0
	  	   OTHERS kp*error
  
   Pexb'=ZONE ((ki*error>0) AND Pexb>=0) 0
         OTHERS ki*error
		
	Pexceso=Pexb+Pexa
		
	PotTur=ZONE((Ptotal+Pexceso<=0) AND (Pexceso<0)) 0
	  	    OTHERS Ptotal+Pexceso

	PgridTurbinaa.PgTurb=PotTur
	
	
if((Ptotal+Pexceso)<=0 && Pexceso<0)
Vpv=Vpvant;
nlimi=0; 
    
else
Plimit=Ptotal+Pexceso;
Vpv=Plimit/Iscg;
nlimi=1;
end

*/

	
END COMPONENT



COMPONENT InversorMasterBateria
	"Inversor bateras CA/CC"

-- Considerando los equipo SMA, en este caso hemos seleecionado el Sunny Island
-- el inversor recibe la potencia suministrada por la turbina de viento, el sol y el generador diesel
-- y la potencia consumida por la carga. Con esta informacin, calcula la frecuencia de red
-- con el propositor de limitar o no la potencia suministrada por el sol y la turbina de viento


PORTS

----------------------------------------------------------------------------
-- Entradas: Pgrid 
----------------------------------------------------------------------------
	
		IN RedPuertos							RedPuertosb		

----------------------------------------------------------------------------
-- salidas: fgrid
----------------------------------------------------------------------------

     OUT SBSIV								SBSIVb
     OUT WBSIV								WBSIVb

DATA

	REAL fnom=50					   "Frecuencia nominal (Hz)"
	REAL Unom=230					   "Voltaje efectivo nominal (V)"
	REAL kpf=-1						   "Droop Frecuencia/Potencia Activa (%Hz/W)"
	REAL kqu=-6						"Droop Voltaje/Potencia Reactiva (%Volts/Var)"
	REAL Kpph=0.00043 			   "Droop angulo fase/Potencia Activa (rad/W)"
	REAL Ti=0.2							   "Constante de tiempo de primer orden"
	REAL Pnom=5000				   	"Potencia activa nominal en el bus AC (W)"  -- SI4500, para SI5048 poner 4750
	REAL Qnom=5000					"Potencia reactiva nominal en el bus AC (Var)"  -- SI4500, para SI5048 poner 4750
	REAL fbat=0							"Desviacion de la frecuencia por SOC (Hz)"
	
	
DECLS
	
	REAL Pfstatic						"Variacin de frecuencia en funcion P (Hz)"
	REAL QUstatic						"Variacin del Voltaje en funcion Q (V)"
	REAL Pphstatic							"Variacin del angulo en funcion P (rad)"	
	REAL fgrid								"Frecuencia de red (Hz)"
	REAL Pgrid								"Potencia activa presente en el bus AC (W)"
	REAL Plag								"Potencia activa desacoplada presente en el bus AC (W)"
	REAL Aon									"Angulo de red (rad)"
	REAL Aocorn								"Angulo de red con correcion de fase(rad)"
	REAL Wacn								"Velocidad angular de la red (rad/seg)"
	
	REAL UA 								
	REAL Uabs
	REAL Qlag
	REAL Qgrid
	REAL cosfi
	REAL I

INIT

  Plag=0
  Aon=0
  
  Qlag=0


CONTINUOUS

	
	Pgrid=RedPuertosb.Pgrid	
	
	cosfi=RedPuertosb.cosfi
	I=RedPuertosb.I

-- Desacople de las potencias activa y reactiva presente en la red         
          
		Ti*Plag'+Plag=Pgrid
		Ti*Qlag'+Qlag=Qgrid
		
-- Droop de la frecuencia de red en funcion de la potencia activa

		Pfstatic=kpf*(Plag/Pnom)

-- Calculo de la frecuencia de red considerando ambos efectos

		fgrid=fnom+Pfstatic+fbat   -- Valor en Hz	
		Wacn=2*PI*fgrid
		Aon'=Wacn

-- Droop del angulo de fase en funcion de la potencia activa

		Pphstatic=Kpph*(Plag/Pnom)
		Aocorn=Aon+Pphstatic   -- Correcion de fase de referencia en las tres fases


-- Droop del voltaje de red en funcion de la potencia reactiva

		QUstatic=(kqu/100)*(Qlag/Qnom)

		Uabs=(1+QUstatic) -- Valor en RMS
                  
		UA=(Uabs/1000)*Unom*sqrt(2)  -- Magnitud del voltaje de referencia en la fase A*/
		
	
		SBSIVb.fac=fgrid
		WBSIVb.fac=fgrid
		
		SBSIVb.Vmb=UA
		WBSIVb.Vmb=UA
		
		SBSIVb.cosfi=cosfi
		SBSIVb.I=I
	
		
END COMPONENT


/*

COMPONENT inversor

// modelo del inversor bidireccional de bateria

DATA

-- Gestion de bateria

REAL Cnom=140					"Capacidad nominal de la bateran (Ah)" 
REAL Tref=20					"Temperatura de referencia de la bateria (C)"
REAL beta=-1					"Sensibilidad de la Capacidad de la bateria a la Temepratura (%/C)"
REAL BatChrgCurMax=1200 	"Corriente de la bateria mxima fijada (Amps)"
REAL GnCurNom=16				"Corriente mxima nominal del generador (Amps)"
REAL InvChrgCurMax=20		"Corriente mxima de carga del Sunny Island (Amps)"
REAL ChrgVtgBoost=2.4		"Comienzo de la segunda fase de carga (Volts)"
REAL AptTmBoost=7200			"Duracion de la segunda etapa (seg)"
REAL ChrgVtgFlo=2.25			"Voltaje de mantenimiento (Volts)"

-------------------------------------------------------------------------------

-- Control Droop

REAL fnom=50					"Frecuencia nominal (Hz)"
REAL Unom=230					"Voltaje efectivo nominal (Volts)"
REAL kpf=-2						"Droop Frecuencia/Potencia Activa (%Hz/W)"
REAL kqu=-6						"Droop Voltaje/Potencia Reactiva (%Volts/Var)"
REAL Kpph=-4					"Droop angulo fase/Potencia Activa (rad/W)"
REAL Ti							"Constante de tiempo de primer orden"
REAL Pnom=3600					"Potencia activa nominal en el bus AC (W)"  -- SI4500, para SI5048 poner 4750
REAL Qnom=3600					"Potencia reactiva nominal en el bus AC (Var)"  -- SI4500, para SI5048 poner 4750




DECLS

-- Control Droop

REAL Pfstatic					"Variacin de frecuencia en funcion P (Hz)"
REAL QUstatic					"Variacin del Voltaje en funcion Q (Volts)"
REAL Pphstatic					"Variacin del angulo en funcion P (rad)"	
REAL Ia							"Corriente A del integrador extendido"
REAL Ib							"Corriente B del integrador extendido"
REAL Ua							"Voltaje A del integrador extendido"
REAL Ub							"Voltaje B del integrador extendido"
EXPL REAL Pgrid				"Potencia activa presente en el bus AC (W)"
EXPL REAL Qgrid				"Potencia reactiva presente en el bus AC (Var)"
REAL Qlag						"Potencia reactiva desacoplda presente en el bus AC (Var)"
REAL Plag						"Potencia activa desacoplada presente en el bus AC (W)"
REAL Facn						"Frecuencia de red (Hz)"
REAL Wacn						"Velocidad angular de la red (rad/seg)"
REAL Uabs						"Ajustes del Voltaje de red en la fase A(RMS)"
REAL UA							"Magnitud del Voltaje en la fase A (Volts)"
REAL Aon							"Angulo de red (rad)"
REAL Aocorn						"Angulo de red con correcion de fase(rad)"

-- Battery Management Systems

REAL fbat						"Variacin de frecuencia de red con respecto al SOC (Hz)"
REAL Pc							"Potencia activa disponible en el bus AC"
REAL Pdm							"Potencia activa demandada"
REAL k							"Auxiliar"
REAL SOCp						"Prediccion del estado de carga de las bateras"
REAL C							"Capacidad de la bateria"
REAL Ibat						"Corriente desde el sunny island"
REAL Ibata						"Corriente de la bateria auxiliar"
REAL IcarLim					"Corriente limite de carga"
REAL Tenv						"Temperatura ambiente (C)"
	
	-- Para que la Ibat del modelo de la bateria tenga el mismo sentido que Ibat en el inversor se tiene:
	-- Ibat>0 Cuando la bateria se esta cargando
	-- Ibat<0 Cuando la bateria se esta descargando

-- 
REAL x						"Auxiliar para calcular SOC"
REAL nocar					"Indicador del comienzo de la etapa de carga"
REAL n2car					"Indicador del comienzo de la segunda etapa"
REAL n3car					"Indicador del comienzo de la tercera etapa"
REAL n4des					"Indicador de la etapa de descarga"
REAL Vbat					"Voltaje de la bateria (Volts)"
REAL tini					"Tiempo inicial de la segunda etapa"

-- Falta definir

REAL Imed					"Corriente medida en el bus AC"
REAL Umed					"Voltaje medido en el bus AC"

DISCRETE

---------------------------------------------------------------------------
--          CONDICIONES DE CARGA Y DESCARGA DE LA BATERIA
---------------------------------------------------------------------------

/*WHEN (condiciones de potencia AND (Vbat<ChrgVtgBoost) AND (SOCp<0.7)) THEN 		--Inicio de la etapa de carga
		nocar=1		"Enciendo la etapa de carga"
		n4des=0		"Cierro la etapa de descarga"
END WHEN 
*/

/*
WHEN (condiciones de potencia AND (Vbat>=ChrgVtgBoost) AND (SOCp<0.7)) THEN 		--Inicio de la segunda etapa de carga
		n2car=1		"Abro la segunda etapa"
		nocar=0		"Cierro la etapa de carga"
		n4des=0		"Cierro la etapa de descarga"
		tini=TIME+AptTmBoost
END WHEN 

WHEN (condiciones de potencia AND (SOCb>0.7)) THEN 		--Inicio de la segunda etapa de carga
		n3car=1
		n4des=0		"Cierro la etapa de descarga"
END WHEN 
*/
/*

WHEN ((TIME>=tini) AND (n2car==1)) THEN 		--Segunda etapa a la etapa de mantenimiento
		n2car=0
		n3car=1		
END WHEN 


WHEN ((n3car==1) AND (SOCp<0.7)) THEN 		--etapa de mantenimiento a la segunda etapa
		n3car=0
		n2car=1		
END WHEN 

/*WHEN (condiciones de potencia) THEN 		--Inicio de la etapa de descarga

		n4des=1  	"Enciendo la etapa de descarga"
		n2car=0		"Cierro la segunda etapa"
		n3car=0		"Cierro la etapa de mantenimiento"
		nocar=0		"Cierro la etapa de carga"
END WHEN 
*/

---------------------------------------------------------------------------
/*
CONTINUOUS

---------------------------------------------------------------------------
--                        BATTERY MANAGMENT 
---------------------------------------------------------------------------

---------------------------------------------------------------------------
-- Cambio de la frecuencia de red de acuerdo al SOC de las baterias
---------------------------------------------------------------------------

	-- Estimacin del SOC
	
	x'= Ibat  -- Falta lo de la eficiencia revisar!!!
	
	C= Cnom*(1+(beta*abs(Tref-Tenv)/100))  -- Efectos de la tempratura sobre la capacidad
	
	SOCp=(1/C)*x  -- Falta incluir las perdidas por autodescarga y gaseo
	
	-- El sunny Island solo activa tres fases de operacion:
	-- a) Descarga: energa almacenada en energa electrica (Voltaje DC negativo)
	-- La descarga termina cuando se alcanza el voltaje de descarga final
	-- b) Carga: energia es almacenada en la bateria despues de una descarga previa (Voltaje DC Positivo)
	-- c) Carga de mantenimiento: Se mantiene el nivel de energa en la bateria (Autodescarga)
	-- Una vez que el voltaje de bateria alcanza el voltaje de carga , la corriente de carga
	-- disminuye hasta llegar a cero.
	
	-----------------------------------------------------------------------------------------------
	-- Definicion de la corriente de la bateria
	-----------------------------------------------------------------------------------------------	
	
	/*
	Ibat= ZONE (nocar==1) Ecuacion de corriente constante de carga
			ZONE (n2car==1) ecuacion de disminucion de la corriente (mas rapido)  -- Considerar el voltaje ChrgVtgBoost
			ZONE (n3car==1) Ecuacion de disminucion de corriente hasta llegar a cero (mas lento) -- Considerar el voltaje ChrgVtgFlo 
			ZONE (n4des==1) Ecuacion de corriente constante de descarga
			OTHERS 0
	*/
	
	-----------------------------------------------------------------------------------------------
	-- Limitacion de la corriente de carga
	-----------------------------------------------------------------------------------------------	
	/*
		IcarLim= ZONE ((BatChrgCurMax<=GnCurNom) AND (BatChrgCurMax<=InvChrgCurMax))  BatChrgCurMax
					ZONE ((GnCurNom<=BatChrgCurMax) AND (GnCurNom<=InvChrgCurMax)) GnCurNom
					ZONE ((InvChrgCurMax<=GnCurNom) AND (InvChrgCurMax<=BatChrgCurMax)) InvChrgCurMax
					OTHERS 0
					
		Ibata= ZONE (Ibat>=IcarLim) IcarLim
		       OTHERS Ibat 
	

		fbat'= ZONE (Pc>Pdm) k*SOCp
				 ZONE (Pc<Pdm) -k*SOCp
		       OTHERS 0


---------------------------------------------------------------------------
--                        CONTROL DROOP 
---------------------------------------------------------------------------

-- Integrador extendido para el voltaje del bus AC   
          
		Ua'=2*50*PI*((sqrt(2)*(Umed-Ua))-Ub)
		Ub'=2*50*PI*Ua

-- Integrador extendido para la corriente del bus AC   
          
		Ia'=2*50*PI*((sqrt(2)*(Imed-Ia))-Ib)
		Ib'=2*50*PI*Ia

-- Potencia activa y reactiva presente en la red
 
		Pgrid=0.5*((Ua*Ia)+(Ub*Ib))

		Qgrid=0.5*((Ub*Ia)-(Ua*Ib))

-- Desacople de las potencias activa y reactiva presente en la red         
          
		Ti*Plag'+Plag=Pgrid
		Ti*Qlag'+Qlag=Qgrid

-- Droop de la frecuencia de red en funcion de la potencia activa

		Pfstatic=kpf*(Plag/Pnom)

-- Calculo de la frecuencia de red considerando ambos efectos

		Facn=fnom+Pfstatic+fbat   -- Valor en Hz
		Wacn=2*PI*Facn
		Aon'=Wacn

-- Droop del angulo de fase en funcion de la potencia activa

		Pphstatic=Kpph*(Plag/Pnom)
		Aocorn=Aon+Pphstatic   -- Correcion de fase de referencia en las tres fases

-- Droop del voltaje de red en funcion de la potencia reactiva

		QUstatic=(kqu/100)*(Qlag/Qnom)

		Uabs=(1+QUstatic) -- Valor en RMS
                  
		UA=(Uabs/1000)*Unom*sqrt(2)  -- Magnitud del voltaje de referencia en la fase A

---------------------------------------------------------------------------
--            CONTROLADOR
---------------------------------------------------------------------------	

-- Entradas al controlador:
-- a) Corriente medida
-- b) Voltaje de referencia

-- Salidas del controlador:
-- a) El voltaje generado por la fuente de voltaje AC
-- b) Corriente del capacitor del filtro incluido	
		
	int1out'=VIP3a*(((UA-Uinvout)*VIP1)-int2in)
	
	int2out'=VIP3b*(int1in)
	
	Iref=((UA-Uinvout)*VIP2)+int1in
	
	S13= (((Iref*Kuadapt-IC)*Kcurrentp)+UA)
	
	IC'= ((S13-(UL+Uinvout))*(1/KreactorL))-Igrid'	
	
	UL'= KreactorR*(1/KreactorL)*(S13-(UL+Uinvout))
	
	Uinvout'= (1/KcapC)*(IC-(KcapR*Uinvout))

---------------------------------------------------------------------------

END COMPONENT


COMPONENT invslave

// Modelo del inversor esclavo de bateria

DATA

REAL Unom=230				"Voltaje efectivo nominal (Volts)"
REAL kqu=-6					"Droop Voltaje/Potencia Reactiva (%Volts/Var)"
REAL Ti						"Constante de tiempo de primer orden"

DECLS

REAL QUstatic				"Variacin del Voltaje en funcion Q (Volts)"
			

REAL Uabs					"Ajustes del Voltaje de red en la fase A(RMS)"
REAL UB						"Magnitud del Voltaje en la fase A (Volts)"
REAL Imed					"Corriente medida en el bus AC"
REAL Ia						"Corriente A del integrador extendido"
REAL Ib						"Corriente B del integrador extendido"
REAL Umed					"Voltaje medido en el bus AC"
REAL Ua						"Voltaje A del integrador extendido"
REAL Ub						"Voltaje B del integrador extendido"

REAL Qgrid					"Potencia reactiva presente en el bus AC (Var)"
REAL Qlag					"Potencia reactiva desacoplda presente en el bus AC (Var)"
REAL Qnom					"Potencia reactiva nominal en el bus AC (Var)"


CONTINUOUS


---------------------------------------------------------------------------
--                        CONTROL DROOP 
---------------------------------------------------------------------------

---------------------------------------------------------------------------
-- Integrador extendido para el voltaje del bus AC
---------------------------------------------------------------------------      
          
		Ua'=2*50*PI*((sqrt(2)*(Umed-Ua))-Ub)
		Ub'=2*50*PI*Ua

---------------------------------------------------------------------------
-- Integrador extendido para la corriente del bus AC
---------------------------------------------------------------------------      
          
		Ia'=2*50*PI*((sqrt(2)*(Imed-Ia))-Ib)
		Ib'=2*50*PI*Ia


---------------------------------------------------------------------------
-- Potencia activa y reactiva presente en la red
--------------------------------------------------------------------------- 

		Qgrid=0.5*((Ub*Ia)-(Ua*Ib))

---------------------------------------------------------------------------
-- Desacople de las potencias activa y reactiva presente en la red
---------------------------------------------------------------------------          
          
		Ti*Qlag'+Qlag=Qgrid

---------------------------------------------------------------------------
-- Droop del voltaje de red en funcion de la potencia reactiva
---------------------------------------------------------------------------

		QUstatic=(kqu/100)*(Qlag/Qnom)

		Uabs=(1+QUstatic) -- Valor en RMS

		UB=(Uabs/1000)*Unom*sqrt(2)


END COMPONENT */